@@ -28,7 +28,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: iocanxx.h,v 1.1.2.3 2006/05/03 14:27:51 aesok Exp $ */
+/* $Id: iocanxx.h,v 1.1.2.6 2007/10/25 20:34:15 aesok Exp $ */
 
 /* This file is based largely on:
    - iom128.h by Peter Jansen (bit defines)
@@ -547,14 +547,17 @@
 /* USART0, Rx Complete */
 #define USART0_RX_vect			_VECTOR(21)
 #define SIG_UART0_RECV			_VECTOR(21)
+#define SIG_USART0_RECV			_VECTOR(21)
 
 /* USART0 Data Register Empty */
 #define USART0_UDRE_vect		_VECTOR(22)
 #define SIG_UART0_DATA			_VECTOR(22)
+#define SIG_USART0_DATA			_VECTOR(22)
 
 /* USART0, Tx Complete */
 #define USART0_TX_vect			_VECTOR(23)
 #define SIG_UART0_TRANS			_VECTOR(23)
+#define SIG_USART0_TRANS		_VECTOR(23)
 
 /* Analog Comparator */
 #define ANALOG_COMP_vect		_VECTOR(24)
@@ -591,14 +594,17 @@
 /* USART1, Rx Complete */
 #define USART1_RX_vect			_VECTOR(32)
 #define SIG_UART1_RECV			_VECTOR(32)
+#define SIG_USART1_RECV			_VECTOR(32)
 
 /* USART1, Data Register Empty */
 #define USART1_UDRE_vect		_VECTOR(33)
 #define SIG_UART1_DATA			_VECTOR(33)
+#define SIG_USART1_DATA			_VECTOR(33)
 
 /* USART1, Tx Complete */
 #define USART1_TX_vect			_VECTOR(34)
 #define SIG_UART1_TRANS			_VECTOR(34)
+#define SIG_USART1_TRANS		_VECTOR(34)
 
 /* 2-wire Serial Interface */
 #define TWI_vect			_VECTOR(35)
@@ -608,7 +614,6 @@
 #define SPM_READY_vect			_VECTOR(36)
 #define SIG_SPM_READY			_VECTOR(36)
 
-
 #define _VECTORS_SIZE 148
 
 /* The Register Bit names are represented by their bit number (0-7). */
@@ -1477,6 +1482,7 @@
 
 /* Register Bits [CANGSTA]  */
 /* CAN General Status Register */
+#define    OVFG       6
 #define    OVRG       6
 #define    TXBSY      4
 #define    RXBSY      3
