@@ -1,4 +1,5 @@
 /* Copyright (c) 2002, Peter Jansen
+   Copyright (c) 2007, Atmel Corporation
    All rights reserved.
 
    Redistribution and use in source and binary forms, with or without
@@ -28,7 +29,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: iom128.h,v 1.18 2005/10/30 22:11:23 joerg_wunsch Exp $ */
+/* $Id: iom128.h,v 1.18.2.2 2007/10/25 01:15:06 arcanum Exp $ */
 
 /* avr/iom128.h - defines for ATmega128 
 
@@ -1153,4 +1154,48 @@
 #define    E2END    0x0FFF
 #define    FLASHEND 0x1FFFF
 
+
+/* Fuses */
+
+#define FUSE_MEMORY_SIZE 3
+
+/* Low Fuse Byte */
+#define CKSEL0      ~_BV(0)
+#define CKSEL1      ~_BV(1)
+#define CKSEL2      ~_BV(2)
+#define CKSEL3      ~_BV(3)
+#define SUT0        ~_BV(4)
+#define SUT1        ~_BV(5)
+#define BODEN       ~_BV(6)
+#define BODLEVEL    ~_BV(7)
+
+#define LFUSE_DEFAULT (SUT0 & CKSEL3 & CKSEL2 & CKSEL1)
+
+
+/* High Fuse Byte */
+#define BOOTRST     ~_BV(0)
+#define BOOTSZ0     ~_BV(1)
+#define BOOTSZ1     ~_BV(2)
+#define EESAVE      ~_BV(3)
+#define CKOPT       ~_BV(4)
+#define SPIEN       ~_BV(5)
+#define JTAGEN      ~_BV(6)
+#define OCDEN       ~_BV(7)
+
+#define HFUSE_DEFAULT (JTAGEN & SPIEN & BOOTSZ1 & BOOTSZ0)
+
+
+/* Extended Fuse Byte */
+#define WDTON       ~_BV(0)
+#define M103C       ~_BV(1)
+
+#define EFUSE_DEFAULT (M103C)
+
+
+/* Lock Bits */
+#define __LOCK_BITS_EXIST
+#define __BOOT_LOCK_BITS_0_EXIST
+#define __BOOT_LOCK_BITS_1_EXIST 
+
+
 #endif /* _AVR_IOM128_H_ */
