@@ -28,7 +28,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: iom8.h,v 1.9 2004/11/01 22:23:56 arcanum Exp $ */
+/* $Id: iom8.h,v 1.13 2005/10/30 22:11:23 joerg_wunsch Exp $ */
 
 /* avr/iom8.h - definitions for ATmega8 */
 
@@ -95,7 +95,16 @@
 #define DDRB	_SFR_IO8(0x17)
 #define PORTB	_SFR_IO8(0x18)
 
-/* 0x1C..0x1F EEPROM */
+/* EEPROM Control Register */
+#define EECR	_SFR_IO8(0x1C)
+
+/* EEPROM Data Register */
+#define EEDR	_SFR_IO8(0x1D)
+
+/* EEPROM Address Register */
+#define EEAR	_SFR_IO16(0x1E)
+#define EEARL	_SFR_IO8(0x1E)
+#define EEARH	_SFR_IO8(0x1F)
 
 #define UCSRC	_SFR_IO8(0x20)
 #define UBRRH	_SFR_IO8(0x20)
@@ -154,24 +163,77 @@
 
 /* Interrupt vectors */
 
-#define SIG_INTERRUPT0		_VECTOR(1)
-#define SIG_INTERRUPT1		_VECTOR(2)
-#define SIG_OUTPUT_COMPARE2	_VECTOR(3)
-#define SIG_OVERFLOW2		_VECTOR(4)
-#define SIG_INPUT_CAPTURE1	_VECTOR(5)
-#define SIG_OUTPUT_COMPARE1A	_VECTOR(6)
-#define SIG_OUTPUT_COMPARE1B	_VECTOR(7)
-#define SIG_OVERFLOW1		_VECTOR(8)
-#define SIG_OVERFLOW0		_VECTOR(9)
-#define SIG_SPI			_VECTOR(10)
-#define SIG_UART_RECV		_VECTOR(11)
-#define SIG_UART_DATA		_VECTOR(12)
-#define SIG_UART_TRANS		_VECTOR(13)
-#define SIG_ADC			_VECTOR(14)
-#define SIG_EEPROM_READY	_VECTOR(15)
-#define SIG_COMPARATOR		_VECTOR(16)
-#define SIG_2WIRE_SERIAL	_VECTOR(17)
-#define SIG_SPM_READY		_VECTOR(18)
+/* External Interrupt Request 0 */
+#define INT0_vect			_VECTOR(1)
+#define SIG_INTERRUPT0			_VECTOR(1)
+
+/* External Interrupt Request 1 */
+#define INT1_vect			_VECTOR(2)
+#define SIG_INTERRUPT1			_VECTOR(2)
+
+/* Timer/Counter2 Compare Match */
+#define TIMER2_COMP_vect		_VECTOR(3)
+#define SIG_OUTPUT_COMPARE2		_VECTOR(3)
+
+/* Timer/Counter2 Overflow */
+#define TIMER2_OVF_vect			_VECTOR(4)
+#define SIG_OVERFLOW2			_VECTOR(4)
+
+/* Timer/Counter1 Capture Event */
+#define TIMER1_CAPT_vect		_VECTOR(5)
+#define SIG_INPUT_CAPTURE1		_VECTOR(5)
+
+/* Timer/Counter1 Compare Match A */
+#define TIMER1_COMPA_vect		_VECTOR(6)
+#define SIG_OUTPUT_COMPARE1A		_VECTOR(6)
+
+/* Timer/Counter1 Compare Match B */
+#define TIMER1_COMPB_vect		_VECTOR(7)
+#define SIG_OUTPUT_COMPARE1B		_VECTOR(7)
+
+/* Timer/Counter1 Overflow */
+#define TIMER1_OVF_vect			_VECTOR(8)
+#define SIG_OVERFLOW1			_VECTOR(8)
+
+/* Timer/Counter0 Overflow */
+#define TIMER0_OVF_vect			_VECTOR(9)
+#define SIG_OVERFLOW0			_VECTOR(9)
+
+/* Serial Transfer Complete */
+#define SPI_STC_vect			_VECTOR(10)
+#define SIG_SPI				_VECTOR(10)
+
+/* USART, Rx Complete */
+#define USART_RXC_vect			_VECTOR(11)
+#define SIG_UART_RECV			_VECTOR(11)
+
+/* USART Data Register Empty */
+#define USART_UDRE_vect			_VECTOR(12)
+#define SIG_UART_DATA			_VECTOR(12)
+
+/* USART, Tx Complete */
+#define USART_TXC_vect			_VECTOR(13)
+#define SIG_UART_TRANS			_VECTOR(13)
+
+/* ADC Conversion Complete */
+#define ADC_vect			_VECTOR(14)
+#define SIG_ADC				_VECTOR(14)
+
+/* EEPROM Ready */
+#define EE_RDY_vect			_VECTOR(15)
+#define SIG_EEPROM_READY		_VECTOR(15)
+
+/* Analog Comparator */
+#define ANA_COMP_vect			_VECTOR(16)
+#define SIG_COMPARATOR			_VECTOR(16)
+
+/* 2-wire Serial Interface */
+#define TWI_vect			_VECTOR(17)
+#define SIG_2WIRE_SERIAL		_VECTOR(17)
+
+/* Store Program Memory Ready */
+#define SPM_RDY_vect			_VECTOR(18)
+#define SIG_SPM_READY			_VECTOR(18)
 
 #define _VECTORS_SIZE 38
 
@@ -264,9 +326,14 @@
 #define EXTRF	1
 #define PORF	0
 
+/* 
+   The ADHSM bit has been removed from all documentation, 
+   as being not needed at all since the comparator has proven 
+   to be fast enough even without feeding it more power.
+*/
+
 /* SFIOR */
 /* bits 7-5 reserved */
-#define ADHSM	4
 #define ACME	3
 #define PUD	2
 #define PSR2	1
@@ -488,6 +555,12 @@
 #define MUX1	1
 #define MUX0	0
 
+/* EEPROM Control Register */
+#define EERIE   3
+#define EEMWE   2
+#define EEWE    1
+#define EERE    0
+
 /* Constants */
 #define SPM_PAGESIZE 64
 #define RAMEND		0x45F
