@@ -28,7 +28,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: iom8515.h,v 1.8 2005/10/30 22:11:23 joerg_wunsch Exp $ */
+/* $Id: iom8515.h,v 1.8.2.1 2007/10/19 21:21:07 arcanum Exp $ */
 
 /* avr/iom8515.h - definitions for ATmega8515 */
 
@@ -241,16 +241,19 @@
 #define SIG_SPI				_VECTOR(8)
 
 /* UART, Rx Complete */
-#define UART_RX_vect			_VECTOR(9)
-#define SIG_UART_RECV			_VECTOR(9)
+#define USART_RX_vect                   _VECTOR(9)
+#define UART_RX_vect                    _VECTOR(9) /* For compatability only */
+#define SIG_UART_RECV                   _VECTOR(9) /* For compatability only */
 
 /* UART Data Register Empty */
-#define UART_UDRE_vect			_VECTOR(10)
-#define SIG_UART_DATA			_VECTOR(10)
+#define USART_UDRE_vect                 _VECTOR(10)
+#define UART_UDRE_vect                  _VECTOR(10) /* For compatability only */
+#define SIG_UART_DATA                   _VECTOR(10) /* For compatability only */
 
 /* UART, Tx Complete */
-#define UART_TX_vect			_VECTOR(11)
-#define SIG_UART_TRANS			_VECTOR(11)
+#define USART_TX_vect                   _VECTOR(11)
+#define UART_TX_vect                    _VECTOR(11) /* For compatability only */
+#define SIG_UART_TRANS                  _VECTOR(11) /* For compatability only */
 
 /* Analog Comparator */
 #define ANA_COMP_vect			_VECTOR(12)
