@@ -1,4 +1,4 @@
-/* Copyright (c) 2002, Marek Michalkiewicz
+/* Copyright (c) 2002,2005 Marek Michalkiewicz
    All rights reserved.
 
    Redistribution and use in source and binary forms, with or without
@@ -28,7 +28,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: iotn15.h,v 1.6 2004/11/01 22:23:56 arcanum Exp $ */
+/* $Id: iotn15.h,v 1.11 2005/11/10 22:19:07 joerg_wunsch Exp $ */
 
 /* avr/iotn15.h - definitions for ATtiny15 */
 
@@ -55,6 +55,9 @@
 
 /* 0x00..0x03 reserved */
 
+#ifndef __ASSEMBLER__
+#define ADC     _SFR_IO16 (0x04)
+#endif
 #define ADCW	_SFR_IO16(0x04)
 #define ADCL	_SFR_IO8(0x04)
 #define ADCH	_SFR_IO8(0x05)
@@ -77,7 +80,15 @@
 
 /* 0x19..0x1B reserved */
 
-/* 0x1C..0x1E EEPROM */
+/* EEPROM Control Register */
+#define EECR	_SFR_IO8(0x1C)
+
+/* EEPROM Data Register */
+#define EEDR	_SFR_IO8(0x1D)
+
+/* EEPROM Address Register */
+#define EEAR	_SFR_IO8(0x1E)
+#define EEARL	_SFR_IO8(0x1E)
 
 /* 0x1F..0x20 reserved */
 
@@ -127,14 +138,38 @@
 
 /* Interrupt vectors */
 
-#define SIG_INTERRUPT0		_VECTOR(1)
-#define SIG_PIN			_VECTOR(2)
-#define SIG_OUTPUT_COMPARE1A	_VECTOR(3)
-#define SIG_OVERFLOW1		_VECTOR(4)
-#define SIG_OVERFLOW0		_VECTOR(5)
-#define SIG_EEPROM_READY	_VECTOR(6)
-#define SIG_COMPARATOR		_VECTOR(7)
-#define SIG_ADC			_VECTOR(8)
+/* External Interrupt 0 */
+#define INT0_vect			_VECTOR(1)
+#define SIG_INTERRUPT0			_VECTOR(1)
+
+/* External Interrupt Request 0 */
+#define IO_PINS_vect			_VECTOR(2)
+#define SIG_PIN				_VECTOR(2)
+#define SIG_PIN_CHANGE			_VECTOR(2)
+
+/* Timer/Counter1 Compare Match */
+#define TIMER1_COMP_vect		_VECTOR(3)
+#define SIG_OUTPUT_COMPARE1A		_VECTOR(3)
+
+/* Timer/Counter1 Overflow */
+#define TIMER1_OVF_vect			_VECTOR(4)
+#define SIG_OVERFLOW1			_VECTOR(4)
+
+/* Timer/Counter0 Overflow */
+#define TIMER0_OVF_vect			_VECTOR(5)
+#define SIG_OVERFLOW0			_VECTOR(5)
+
+/* EEPROM Ready */
+#define EE_RDY_vect			_VECTOR(6)
+#define SIG_EEPROM_READY		_VECTOR(6)
+
+/* Analog Comparator */
+#define ANA_COMP_vect			_VECTOR(7)
+#define SIG_COMPARATOR			_VECTOR(7)
+
+/* ADC Conversion Ready */
+#define ADC_vect			_VECTOR(8)
+#define SIG_ADC				_VECTOR(8)
 
 #define _VECTORS_SIZE 18
 
@@ -257,6 +292,12 @@
 #define ADPS1	1
 #define ADPS0	0
 
+/* EEPROM Control Register */
+#define EERIE   3
+#define EEMWE   2
+#define EEWE    1
+#define EERE    0
+
 /* Last memory addresses */
 #define RAMEND		0x1F
 #define XRAMEND		0x0
