@@ -1,4 +1,4 @@
-/* Copyright (c) 2002, 2003, 2004  Marek Michalkiewicz
+/* Copyright (c) 2002 - 2007  Marek Michalkiewicz
    All rights reserved.
 
    Redistribution and use in source and binary forms, with or without
@@ -26,7 +26,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: pgmspace.h,v 1.22.2.1 2005/01/18 16:28:05 joerg_wunsch Exp $ */
+/* $Id: pgmspace.h,v 1.26.2.8 2007/03/31 23:17:23 dmix Exp $ */
 
 /*
    pgmspace.h
@@ -37,7 +37,8 @@
      Wolfgang Haidinger <wh@vmars.tuwien.ac.at> (pgm_read_dword())
  */
 
-/** \defgroup avr_pgmspace Program Space String Utilities
+/** \file */
+/** \defgroup avr_pgmspace <avr/pgmspace.h>: Program Space Utilities
     \code
     #include <avr/io.h>
     #include <avr/pgmspace.h>
@@ -56,10 +57,20 @@
     \note If you are working with strings which are completely based in ram,
     use the standard string functions described in \ref avr_string.
 
-    \note If possible, put your constant tables in the lower 64K and use
+    \note If possible, put your constant tables in the lower 64 KB and use
     pgm_read_byte_near() or pgm_read_word_near() instead of
     pgm_read_byte_far() or pgm_read_word_far() since it is more efficient that
-    way, and you can still use the upper 64K for executable code. */
+    way, and you can still use the upper 64K for executable code.
+    All functions that are suffixed with a \c _P \e require their
+    arguments to be in the lower 64 KB of the flash ROM, as they do
+    not use ELPM instructions.  This is normally not a big concern as
+    the linker setup arranges any program space constants declared
+    using the macros from this header file so they are placed right after
+    the interrupt vectors, and in front of any executable code.  However,
+    it can become a problem if there are too many of these constants, or
+    for bootloaders on devices with more than 64 KB of ROM.
+    <em>All these functions will not work in that situation.</em>
+*/
 
 #ifndef __PGMSPACE_H_
 #define __PGMSPACE_H_ 1
@@ -81,12 +92,121 @@
 #define __ATTR_PURE__ __attribute__((__pure__))
 #endif
 
+/**
+   \ingroup avr_pgmspace
+   \def PROGMEM
+
+   Attribute to use in order to declare an object being located in
+   flash ROM.
+ */
 #define PROGMEM __ATTR_PROGMEM__
 
 #ifdef __cplusplus
 extern "C" {
 #endif
 
+#if defined(__DOXYGEN__)
+/*
+ * Doxygen doesn't grok the appended attribute syntax of
+ * GCC, and confuses the typedefs with function decls, so
+ * supply a doxygen-friendly view.
+ */
+/**
+   \ingroup avr_pgmspace
+   \typedef prog_void
+
+   Type of a "void" object located in flash ROM.  Does not make much
+   sense by itself, but can be used to declare a "void *" object in
+   flash ROM.
+*/
+typedef void PROGMEM prog_void;
+/**
+   \ingroup avr_pgmspace
+   \typedef prog_char
+
+   Type of a "char" object located in flash ROM.
+*/
+typedef char PROGMEM prog_char;
+
+/**
+   \ingroup avr_pgmspace
+   \typedef prog_uchar
+
+   Type of an "unsigned char" object located in flash ROM.
+*/
+typedef unsigned char PROGMEM prog_uchar;
+
+
+/**
+   \ingroup avr_pgmspace
+   \typedef prog_int8_t
+
+   Type of an "int8_t" object located in flash ROM.
+*/
+typedef int8_t PROGMEM prog_int8_t;
+
+/**
+   \ingroup avr_pgmspace
+   \typedef prog_uint8_t
+
+   Type of an "uint8_t" object located in flash ROM.
+*/
+typedef uint8_t PROGMEM prog_uint8_t;
+
+/**
+   \ingroup avr_pgmspace
+   \typedef prog_int16_t
+
+   Type of an "int16_t" object located in flash ROM.
+*/
+typedef int16_t PROGMEM prog_int16_t;
+
+/**
+   \ingroup avr_pgmspace
+   \typedef prog_uint16_t
+
+   Type of an "uint16_t" object located in flash ROM.
+*/
+typedef uint16_t PROGMEM prog_uint16_t;
+
+/**
+   \ingroup avr_pgmspace
+   \typedef prog_int32_t
+
+   Type of an "int32_t" object located in flash ROM.
+*/
+typedef int32_t PROGMEM prog_int32_t;
+
+/**
+   \ingroup avr_pgmspace
+   \typedef prog_uint32_t
+
+   Type of an "uint32_t" object located in flash ROM.
+*/
+typedef uint32_t PROGMEM prog_uint32_t;
+
+/**
+   \ingroup avr_pgmspace
+   \typedef prog_int64_t
+
+   Type of an "int64_t" object located in flash ROM.
+
+   \note This type is not available when the compiler
+   option -mint8 is in effect.
+*/
+typedef int64_t PROGMEM prog_int64_t;
+
+/**
+   \ingroup avr_pgmspace
+   \typedef prog_uint64_t
+
+   Type of an "uint64_t" object located in flash ROM.
+
+   \note This type is not available when the compiler
+   option -mint8 is in effect.
+*/
+typedef uint64_t PROGMEM prog_uint64_t;
+#else  /* !DOXYGEN */
 typedef void prog_void PROGMEM;
 typedef char prog_char PROGMEM;
 typedef unsigned char prog_uchar PROGMEM;
@@ -95,14 +215,13 @@ typedef int8_t    prog_int8_t   PROGMEM;
 typedef uint8_t   prog_uint8_t  PROGMEM;
 typedef int16_t   prog_int16_t  PROGMEM;
 typedef uint16_t  prog_uint16_t PROGMEM;
-#if defined(__HAS_INT32_T__)
 typedef int32_t   prog_int32_t  PROGMEM;
 typedef uint32_t  prog_uint32_t PROGMEM;
-#endif
-#if defined(__HAS_INT64_T__)
+#if !__USING_MINT8
 typedef int64_t   prog_int64_t  PROGMEM;
 typedef uint64_t  prog_uint64_t PROGMEM;
 #endif
+#endif /* defined(__DOXYGEN__) */
 
 /* Although in C, we can get away with just using __c, it does not work in
    C++. We need to use &__c[0] to avoid the compiler puking. Dave Hylands
@@ -114,15 +233,23 @@ typedef uint64_t  prog_uint64_t PROGMEM;
      returned by &__c[0] is a prog_char *, which explains why it works
      fine. */
 
+#if defined(__DOXYGEN__)
+/*
+ * The #define below is just a dummy that serves documentation
+ * purposes only.
+ */
 /** \ingroup avr_pgmspace
     \def PSTR(s)
 
     Used to declare a static pointer to a string in program space. */
-
-#define PSTR(s) ({static char __c[] PROGMEM = (s); &__c[0];})
+# define PSTR(s) ((const PROGMEM char *)(s))
+#else  /* !DOXYGEN */
+/* The real thing. */
+# define PSTR(s) (__extension__({static char __c[] PROGMEM = (s); &__c[0];}))
+#endif /* DOXYGEN */
 
 #define __LPM_classic__(addr)   \
-({                              \
+(__extension__({                \
     uint16_t __addr16 = (uint16_t)(addr); \
     uint8_t __result;           \
     __asm__                     \
@@ -134,10 +261,10 @@ typedef uint64_t  prog_uint64_t PROGMEM;
         : "r0"                  \
     );                          \
     __result;                   \
-})
+}))
 
 #define __LPM_enhanced__(addr)  \
-({                              \
+(__extension__({                \
     uint16_t __addr16 = (uint16_t)(addr); \
     uint8_t __result;           \
     __asm__                     \
@@ -147,10 +274,10 @@ typedef uint64_t  prog_uint64_t PROGMEM;
         : "z" (__addr16)        \
     );                          \
     __result;                   \
-})
+}))
 
 #define __LPM_word_classic__(addr)          \
-({                                          \
+(__extension__({                            \
     uint16_t __addr16 = (uint16_t)(addr);   \
     uint16_t __result;                      \
     __asm__                                 \
@@ -165,10 +292,10 @@ typedef uint64_t  prog_uint64_t PROGMEM;
         : "r0"                              \
     );                                      \
     __result;                               \
-})
+}))
 
 #define __LPM_word_enhanced__(addr)         \
-({                                          \
+(__extension__({                            \
     uint16_t __addr16 = (uint16_t)(addr);   \
     uint16_t __result;                      \
     __asm__                                 \
@@ -179,10 +306,10 @@ typedef uint64_t  prog_uint64_t PROGMEM;
         : "1" (__addr16)                    \
     );                                      \
     __result;                               \
-})
+}))
 
 #define __LPM_dword_classic__(addr)         \
-({                                          \
+(__extension__({                            \
     uint16_t __addr16 = (uint16_t)(addr);   \
     uint32_t __result;                      \
     __asm__                                 \
@@ -203,10 +330,10 @@ typedef uint64_t  prog_uint64_t PROGMEM;
         : "r0"                              \
     );                                      \
     __result;                               \
-})
+}))
 
 #define __LPM_dword_enhanced__(addr)        \
-({                                          \
+(__extension__({                            \
     uint16_t __addr16 = (uint16_t)(addr);   \
     uint32_t __result;                      \
     __asm__                                 \
@@ -219,9 +346,9 @@ typedef uint64_t  prog_uint64_t PROGMEM;
         : "1" (__addr16)                    \
     );                                      \
     __result;                               \
-})
+}))
 
-#if defined (__AVR_ENHANCED__)
+#if defined (__AVR_HAVE_LPMX__)
 #define __LPM(addr)         __LPM_enhanced__(addr)
 #define __LPM_word(addr)    __LPM_word_enhanced__(addr)
 #define __LPM_dword(addr)   __LPM_dword_enhanced__(addr)
@@ -256,18 +383,16 @@ typedef uint64_t  prog_uint64_t PROGMEM;
 #define pgm_read_dword_near(address_short) \
     __LPM_dword((uint16_t)(address_short))
 
-#if defined(RAMPZ) && !defined(__USING_MINT8)
+#if defined(RAMPZ) || defined(__DOXYGEN__)
 
 /* Only for devices with more than 64K of program memory.
    RAMPZ must be defined (see iom103.h, iom128.h).
-
-   These can not be defined if the user is compiling with the -mint8 option
-   since (u)int32_t is not defined in that case. */
+*/
 
 /* The classic functions are needed for ATmega103. */
 
 #define __ELPM_classic__(addr)      \
-({                                  \
+(__extension__({                    \
     uint32_t __addr32 = (uint32_t)(addr); \
     uint8_t __result;               \
     __asm__                         \
@@ -283,10 +408,10 @@ typedef uint64_t  prog_uint64_t PROGMEM;
         : "r0", "r30", "r31"        \
     );                              \
     __result;                       \
-})
+}))
 
 #define __ELPM_enhanced__(addr)     \
-({                                  \
+(__extension__({                    \
     uint32_t __addr32 = (uint32_t)(addr); \
     uint8_t __result;               \
     __asm__                         \
@@ -300,10 +425,10 @@ typedef uint64_t  prog_uint64_t PROGMEM;
         : "r30", "r31"              \
     );                              \
     __result;                       \
-})
+}))
 
 #define __ELPM_word_classic__(addr)     \
-({                                      \
+(__extension__({                        \
     uint32_t __addr32 = (uint32_t)(addr); \
     uint16_t __result;                  \
     __asm__                             \
@@ -325,10 +450,10 @@ typedef uint64_t  prog_uint64_t PROGMEM;
         : "r0", "r30", "r31"            \
     );                                  \
     __result;                           \
-})
+}))
 
 #define __ELPM_word_enhanced__(addr)    \
-({                                      \
+(__extension__({                        \
     uint32_t __addr32 = (uint32_t)(addr); \
     uint16_t __result;                  \
     __asm__                             \
@@ -343,10 +468,10 @@ typedef uint64_t  prog_uint64_t PROGMEM;
         : "r30", "r31"                  \
     );                                  \
     __result;                           \
-})
+}))
 
 #define __ELPM_dword_classic__(addr)      \
-({                                        \
+(__extension__({                          \
     uint32_t __addr32 = (uint32_t)(addr); \
     uint32_t __result;                    \
     __asm__                               \
@@ -380,10 +505,10 @@ typedef uint64_t  prog_uint64_t PROGMEM;
         : "r0", "r30", "r31"              \
     );                                    \
     __result;                             \
-})
+}))
 
 #define __ELPM_dword_enhanced__(addr)     \
-({                                        \
+(__extension__({                          \
     uint32_t __addr32 = (uint32_t)(addr); \
     uint32_t __result;                    \
     __asm__                               \
@@ -400,9 +525,9 @@ typedef uint64_t  prog_uint64_t PROGMEM;
         : "r30", "r31"                    \
     );                                    \
     __result;                             \
-})
+}))
 
-#if defined (__AVR_ENHANCED__)
+#if defined (__AVR_HAVE_LPMX__)
 #define __ELPM(addr)        __ELPM_enhanced__(addr)
 #define __ELPM_word(addr)   __ELPM_word_enhanced__(addr)
 #define __ELPM_dword(addr)  __ELPM_dword_enhanced__(addr)
@@ -439,7 +564,7 @@ typedef uint64_t  prog_uint64_t PROGMEM;
 
 #define pgm_read_dword_far(address_long) __ELPM_dword((uint32_t)(address_long))
 
-#endif /* RAMPZ and ! __USING_MINT8 */
+#endif /* RAMPZ or __DOXYGEN__ */
 
 /** \ingroup avr_pgmspace
     \def pgm_read_byte(address_short)
@@ -487,11 +612,19 @@ typedef uint64_t  prog_uint64_t PROGMEM;
 #define PGM_VOID_P const prog_void *
 #endif
 
+extern PGM_VOID_P memchr_P(PGM_VOID_P s, int val, size_t len) __ATTR_CONST__;
+extern int memcmp_P(const void *, PGM_VOID_P, size_t) __ATTR_PURE__;
 extern void *memcpy_P(void *, PGM_VOID_P, size_t);
+extern void *memmem_P(const void *, size_t, PGM_VOID_P, size_t) __ATTR_PURE__;
+extern PGM_VOID_P memrchr_P(PGM_VOID_P s, int val, size_t len) __ATTR_CONST__;
 extern char *strcat_P(char *, PGM_P);
+extern PGM_P strchr_P(PGM_P s, int val) __ATTR_CONST__;
+extern PGM_P strchrnul_P(PGM_P s, int val) __ATTR_CONST__;
 extern int strcmp_P(const char *, PGM_P) __ATTR_PURE__;
 extern char *strcpy_P(char *, PGM_P);
 extern int strcasecmp_P(const char *, PGM_P) __ATTR_PURE__;
+extern char *strcasestr_P(const char *, PGM_P) __ATTR_PURE__;
+extern size_t strcspn_P(const char *s, PGM_P reject) __ATTR_PURE__;
 extern size_t strlcat_P (char *, PGM_P, size_t );
 extern size_t strlcpy_P (char *, PGM_P, size_t );
 extern size_t strlen_P(PGM_P) __ATTR_CONST__; /* program memory can't change */
@@ -500,15 +633,11 @@ extern int strncmp_P(const char *, PGM_P, size_t) __ATTR_PURE__;
 extern int strncasecmp_P(const char *, PGM_P, size_t) __ATTR_PURE__;
 extern char *strncat_P(char *, PGM_P, size_t);
 extern char *strncpy_P(char *, PGM_P, size_t);
-
-#if 0  /* not implemented yet */
-extern int printf_P(PGM_P, ...);
-extern int puts_P(PGM_P);
-extern int scanf_P(PGM_P, ...);
-extern int sprintf_P(char *, PGM_P, ...);
-extern int sscanf_P(const char *, PGM_P, ...);
-extern PGM_P strerror_P(int);
-#endif
+extern char *strpbrk_P(const char *s, PGM_P accept) __ATTR_PURE__;
+extern PGM_P strrchr_P(PGM_P s, int val) __ATTR_CONST__;
+extern char *strsep_P(char **sp, PGM_P delim);
+extern size_t strspn_P(const char *s, PGM_P accept) __ATTR_PURE__;
+extern char *strstr_P(const char *, PGM_P) __ATTR_PURE__;
 
 #ifdef __cplusplus
 }
