@@ -1,4 +1,5 @@
 /* Copyright (c) 2002, Marek Michalkiewicz
+   Copyright (c) 2004,2007 Joerg Wunsch
 
    Portions of documentation Copyright (c) 1990, 1991, 1993, 1994
    The Regents of the University of California.
@@ -10,11 +11,16 @@
 
    * Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
+
    * Redistributions in binary form must reproduce the above copyright
      notice, this list of conditions and the following disclaimer in
      the documentation and/or other materials provided with the
      distribution.
 
+   * Neither the name of the copyright holders nor the names of
+     contributors may be used to endorse or promote products derived
+     from this software without specific prior written permission.
+
   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
   AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
   IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
@@ -27,7 +33,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE.
 
-  $Id: stdlib.h,v 1.14.2.3 2004/03/08 19:30:07 joerg_wunsch Exp $
+  $Id: stdlib.h,v 1.24.2.3 2007/03/25 14:37:26 dmix Exp $
 */
 
 #ifndef _STDLIB_H_
@@ -48,7 +54,9 @@
 extern "C" {
 #endif
 
-/** \defgroup avr_stdlib General utilities
+/** \file */
+
+/** \defgroup avr_stdlib <stdlib.h>: General utilities
     \code #include <stdlib.h> \endcode
 
     This file declares some basic C macros and functions as
@@ -58,20 +66,20 @@ extern "C" {
 /*@{*/
 /** Result type for function div(). */
 typedef struct {
-	int quot;
-	int rem;
+	int quot;                   /**< The Quotient. */
+	int rem;                    /**< The Remainder. */
 } div_t;
 
 /** Result type for function ldiv(). */
 typedef struct {
-	long quot;
-	long rem;
+	long quot;                  /**< The Quotient. */
+	long rem;                   /**< The Remainder. */
 } ldiv_t;
 
 /** Comparision function type for qsort(), just for convenience. */
 typedef int (*__compar_fn_t)(const void *, const void *);
 
-#ifndef DOXYGEN
+#ifndef __DOXYGEN__
 
 #ifndef __ATTR_CONST__
 #define __ATTR_CONST__ __attribute__((__const__))
@@ -106,7 +114,7 @@ abort(void)
    \note The abs() and labs() functions are builtins of gcc.
 */
 extern int abs(int __i) __ATTR_CONST__;
-#ifndef DOXYGEN
+#ifndef __DOXYGEN__
 #define	abs(__i) __builtin_abs(__i)
 #endif
 
@@ -115,7 +123,7 @@ extern int abs(int __i) __ATTR_CONST__;
    \note The abs() and labs() functions are builtins of gcc.
 */
 extern long labs(long __i) __ATTR_CONST__;
-#ifndef DOXYGEN
+#ifndef __DOXYGEN__
 #define labs(__i) __builtin_labs(__i)
 #endif
 
@@ -240,38 +248,27 @@ extern unsigned long strtoul(const char *__nptr, char **__endptr, int __base);
 
 /**
     The atol() function converts the initial portion of the string
-    pointed to by \c nptr to long integer representation.
+    pointed to by \p s to long integer representation. In contrast to
 
-    It is equivalent to:
+        \code strtol(s, (char **)NULL, 10); \endcode
 
-           \code strtol(nptr, (char **)NULL, 10); \endcode
+    this function does not detect overflow (\c errno is not changed and
+    the result value is not predictable), uses smaller memory (flash and
+    stack) and works more quickly.
 */
-extern __inline__ long atol(const char *__nptr) __ATTR_PURE__;
-extern __inline__ long
-atol(const char *__nptr)
-{
-	return strtol(__nptr, (char **) 0, 10);
-}
+extern long atol(const char *s) __ATTR_PURE__;
 
 /**
     The atoi() function converts the initial portion of the string
-    pointed to by \c nptr to integer representation.
+    pointed to by \p s to integer representation. In contrast to
 
-    It is equivalent to:
+        \code (int)strtol(s, (char **)NULL, 10); \endcode
 
-           \code (int)strtol(nptr, (char **)NULL, 10); \endcode
+    this function does not detect overflow (\c errno is not changed and
+    the result value is not predictable), uses smaller memory (flash and
+    stack) and works more quickly.
 */
-#ifdef DOXYGEN
-extern __inline__ int atoi(const char *__nptr) __ATTR_PURE__;
-extern __inline__ int
-atoi(const char *__nptr)
-{
-	return (int) atol(__nptr);
-}
-#else
-/* optimized asm version, much smaller if strtol() not used elsewhere */
-extern int atoi(const char *) __ATTR_PURE__;
-#endif
+extern int atoi(const char *s) __ATTR_PURE__;
 
 /**
    The exit() function terminates the application.  Since there is no
@@ -325,6 +322,25 @@ extern char *__malloc_heap_end;
 */
 extern void *calloc(size_t __nele, size_t __size) __ATTR_MALLOC__;
 
+/**
+   The realloc() function tries to change the size of the region
+   allocated at \c ptr to the new \c size value.  It returns a
+   pointer to the new region.  The returned pointer might be the
+   same as the old pointer, or a pointer to a completely different
+   region.
+
+   The contents of the returned region up to either the old or the new
+   size value (whatever is less) will be identical to the contents of
+   the old region, even in case a new region had to be allocated.
+
+   It is acceptable to pass \c ptr as NULL, in which case realloc()
+   will behave identical to malloc().
+
+   If the new memory cannot be allocated, realloc() returns NULL, and
+   the region at \c ptr will not be changed.
+*/
+extern void *realloc(void *__ptr, size_t __size) __ATTR_MALLOC__;
+
 /**
      The strtod() function converts the initial portion of the string pointed
      to by \c nptr to double representation.
@@ -357,6 +373,17 @@ extern void *calloc(size_t __nele, size_t __size) __ATTR_MALLOC__;
 
 extern double strtod(const char *__nptr, char **__endptr);
 
+/**
+     The atof() function converts the initial portion of the string pointed
+     to by \c nptr to double representation.
+
+     It is equivalent to calling
+
+     		\code strtod(nptr, (char **)NULL); \endcode
+ */
+
+extern double atof(const char *__nptr);
+
 /** Highest number that can be generated by rand(). */
 #define	RAND_MAX 0x7FFF
 
@@ -542,16 +569,20 @@ extern long random_r(unsigned long *ctx);
  So when linking the application, the \c -lm option needs to be
  specified.
 */
-/** Bit value that can be passed in \c flags to dtostre(). */
+/** \ingroup avr_stdlib
+    Bit value that can be passed in \c flags to dtostre(). */
 #define DTOSTR_ALWAYS_SIGN 0x01        /* put '+' or ' ' for positives */
-/** Bit value that can be passed in \c flags to dtostre(). */
+/** \ingroup avr_stdlib
+    Bit value that can be passed in \c flags to dtostre(). */
 #define DTOSTR_PLUS_SIGN   0x02        /* put '+' rather than ' ' */
-/** Bit value that can be passed in \c flags to dtostre(). */
+/** \ingroup avr_stdlib
+    Bit value that can be passed in \c flags to dtostre(). */
 #define DTOSTR_UPPERCASE   0x04        /* put 'E' rather 'e' */
 
 #ifndef __ASSEMBLER__
 
 /**
+   \ingroup avr_stdlib
    The dtostre() function converts the double value passed in \c val into
    an ASCII representation that will be stored under \c s.  The caller
    is responsible for providing sufficient storage in \c s.
@@ -576,6 +607,7 @@ extern char *dtostre(double __val, char *__s, unsigned char __prec,
 		     unsigned char __flags);
 
 /**
+   \ingroup avr_stdlib
    The dtostrf() function converts the double value passed in \c val into
    an ASCII representationthat will be stored under \c s.  The caller
    is responsible for providing sufficient storage in \c s.
@@ -593,8 +625,6 @@ extern char *dtostrf(double __val, char __width, char __prec, char *__s);
 
 #if 0  /* not yet implemented */
 extern int atexit(void (*)(void));
-extern double atof(const char *);
-extern void *realloc(void *, size_t);
 #endif
 
 #ifdef __cplusplus
